#!/opt/concourse/worker/volumes/live/8a54014a-ff0e-4f02-5833-261aa00d48d8/volume/anaconda-navigator_1636985555062/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/opt/concourse/worker/volumes/live/8a54014a-ff0e-4f02-5833-261aa00d48d8/volume/anaconda-navigator_1636985555062/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin/anaconda-navigator"])
